| data_observed | R Documentation |
data_observed combines the observed dataframe with specific identification
of the columns corresponding to the exposure, outcome, and confounders. It is
an essential input of the multibias_adjust() function.
data_observed(data, bias, exposure, outcome, confounders = NULL)
data |
Dataframe for bias analysis. |
bias |
String type(s) of bias distorting the effect of the exposure on the outcome. Can choose from a subset of the following: "uc", "em", "om", "sel". These correspond to uncontrolled confounding, exposure misclassification, outcome misclassification, and selection bias, respectively. |
exposure |
String name of the column in |
outcome |
String name of the column in |
confounders |
String name(s) of the column(s) in |
An object of class data_observed containing:
data |
A dataframe with the selected columns |
bias |
The type(s) of bias present |
exposure |
The name of the exposure variable |
outcome |
The name of the outcome variable |
confounders |
The name(s) of the confounder variable(s) |
df <- data_observed(
data = df_uc,
bias = "uc",
exposure = "X_bi",
outcome = "Y_bi",
confounders = c("C1", "C2", "C3")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.