| summary.data_observed | R Documentation |
Provides a statistical summary of the observed data by fitting either:
A logistic regression model for binary outcomes
A linear regression model for continuous outcomes
The model includes the exposure and all confounders as predictors. For binary outcomes, estimates are exponentiated to show odds ratios.
## S3 method for class 'data_observed'
summary(object, ...)
object |
A |
... |
Additional arguments passed to summary |
A data frame containing model coefficients, standard errors, confidence intervals, and p-values. For binary outcomes, coefficients are exponentiated to show odds ratios.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.